==> qore-1.8.1.tar.bz2: qore-1.8.1/docs/modules/SalesforceRestDataProvider/html/class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.js <==
var class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider =
[
    [ "constructor", "class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.html#a4b9e9f1acef7b3d018ec20c2fd68a87b", null ],
    [ "constructor", "class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.html#aada4247dc3f319c103105faa7bb67d97", null ],
    [ "getChildProviderImpl", "class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.html#a2326acde69c2fe55e7c868657177e9c7", null ],
    [ "getChildProviderNamesImpl", "class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.html#a8e5f2fd7580f6fc178e53671da8ec8f9", null ],
    [ "getDesc", "class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.html#a0a9f426284ca2b2a6ba8dd77f00a64f8", null ],
    [ "getName", "class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.html#a9f72a5e1b76cb0a693fafdfde8c37481", null ],
    [ "getStaticInfoImpl", "class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.html#a87a6e512a70ed5286028685e2a2aeacd", null ],
    [ "ConstructorOptions", "class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.html#a33f51c8c12c43fd12f8644af6fe0fe6a", null ],
    [ "EnvOptions", "class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.html#a6c1aa464daa809bc4996480c5bb3eb38", null ],
    [ "HttpMethods", "class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.html#a7bc8bc85afe195d60913ecb19fbad1bf", null ],
    [ "ProviderInfo", "class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.html#af9c89ce96b66377f07afc7d83b6dd66a", null ],
    [ "rest", "class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.html#a8a85625eceb8f5ec3fdb943850e8f632", null ]
];

==> qore-1.12.0.tar.bz2: qore-1.12.0/docs/modules/SalesforceRestDataProvider/html/class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.js <==
var class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider =
[
    [ "constructor", "class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.html#a4b9e9f1acef7b3d018ec20c2fd68a87b", null ],
    [ "constructor", "class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.html#aada4247dc3f319c103105faa7bb67d97", null ],
    [ "getChildProviderImpl", "class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.html#a2326acde69c2fe55e7c868657177e9c7", null ],
    [ "getChildProviderNamesImpl", "class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.html#a8e5f2fd7580f6fc178e53671da8ec8f9", null ],
    [ "getChildProviderSummaryInfo", "class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.html#a89826b013d073f7b59b6f45a09553b7c", null ],
    [ "getDesc", "class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.html#a0a9f426284ca2b2a6ba8dd77f00a64f8", null ],
    [ "getName", "class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.html#a9f72a5e1b76cb0a693fafdfde8c37481", null ],
    [ "getStaticInfoImpl", "class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.html#a87a6e512a70ed5286028685e2a2aeacd", null ],
    [ "ConstructorOptions", "class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.html#a33f51c8c12c43fd12f8644af6fe0fe6a", null ],
    [ "EnvOptions", "class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.html#a6c1aa464daa809bc4996480c5bb3eb38", null ],
    [ "HttpMethods", "class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.html#a7bc8bc85afe195d60913ecb19fbad1bf", null ],
    [ "ProviderInfo", "class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.html#af9c89ce96b66377f07afc7d83b6dd66a", null ],
    [ "rest", "class_salesforce_rest_data_provider_1_1_salesforce_rest_data_provider.html#a8a85625eceb8f5ec3fdb943850e8f632", null ]
];
